<?php

/**
 * Implement hook_install_tasks().
 * We hook into the install process to add our own tasks prior to Drupal's final step in the default install process.
 */

function redhen_raiser_install_tasks(){
  $taskset = array(
    'redhen_raiser_custom_install' => array(
      'display_name' => st('RedHen Raiser Setup'),
    ),
  );
  return $taskset;
}

/**
 * Post install tasks.
 */
function redhen_raiser_custom_install(&$install_state) {
  theme_enable(array('zen', 'raiser'));
  variable_set('theme_default', 'raiser');
  variable_set('admin_theme', 'shiny');
  if (module_exists('block')) {
    // Disable DB blocks so we can use context or panels to place everything.
    db_update('block')
      ->fields(array(
        'status' => 0,
        'region' => -1))
      ->condition('status', 1, '=')
      ->condition('theme', 'raiser', '=')
      ->execute();
    // Hide menu block names.
    db_update('block')
      ->fields(array(
        'title' => '<none>'))
      ->condition('delta', 'user-menu', '=')
      ->condition('module', 'system', '=')
      ->execute();
    db_update('block')
      ->fields(array(
        'title' => '<none>'))
      ->condition('delta', 'main-menu', '=')
      ->condition('module', 'system', '=')
      ->execute();
  }

  redhen_raiser_blocks_create_default_blocks();
  module_enable(array('redhen_raiser_defaults'), TRUE);
  module_enable(array('redhen_raiser_custom_config'), TRUE);

  // Turn off the theme rebuild registry setting.
  $theme_settings = variable_get('theme_raiser_settings');
  $theme_settings['zen_rebuild_registry'] = 0;
  variable_set('theme_raiser_settings', $theme_settings);

  drupal_flush_all_caches();
  features_revert();
}
